@@ -19,10 +19,16 @@ GOOGLE_API_FILE_WATCH_KIND = "api#channel"
 GOOGLE_API_TRUE_VAL = "TRUE"
 
 REQUIRED_GOOGLE_SHEETS_SETTINGS = [
-    "MITOL_GOOGLE_SHEET_PROCESSOR_APP_NAME",
-    "MITOL_GOOGLE_SHEETS_DRIVE_SERVICE_ACCOUNT_CREDS",
-    "MITOL_GOOGLE_SHEETS_DRIVE_CLIENT_ID",
-    "MITOL_GOOGLE_SHEETS_DRIVE_CLIENT_SECRET",
+    "MITOL_GOOGLE_SHEETS_PROCESSOR_APP_NAME",
     "MITOL_GOOGLE_SHEETS_DRIVE_API_PROJECT_ID",
     "MITOL_GOOGLE_SHEETS_ENROLLMENT_CHANGE_SHEET_ID",
 ]
+
+REQUIRED_GOOGLE_SHEETS_SERVICE_ACCOUNT_SETTINGS = [
+    "MITOL_GOOGLE_SHEETS_DRIVE_SERVICE_ACCOUNT_CREDS",
+]
+
+REQUIRED_GOOGLE_SHEETS_CLIENT_SETTINGS = [
+    "MITOL_GOOGLE_SHEETS_DRIVE_CLIENT_ID",
+    "MITOL_GOOGLE_SHEETS_DRIVE_CLIENT_SECRET",
+]
